﻿using Windows.Kinect;

namespace KinectModule
{
    public class RealMultiSourceFrame : IMultiSourceFrame
    {
        RealColorFrame     _ColorFrame;
        RealBodyIndexFrame _BodyIndexFrame;
        RealDepthFrame     _DepthFrame;
        RealBodyFrame      _BodyFrame;

        public IColorFrame     LastColorFrame
        {
            get
            {
                return _ColorFrame;
            }
        }
        public IBodyIndexFrame LastBodyIndexFrame
        {
            get
            {
                return _BodyIndexFrame;
            }
        }
        public IDepthFrame     LastDepthFrame
        {
            get
            {
                return _DepthFrame;
            }
        }
        public IBodyFrame      LastBodyFrame
        {
            get
            {
                return _BodyFrame;
            }
        }

        public RealMultiSourceFrame(MultiSourceFrame sourceFrame)
        {
            if (sourceFrame == null)
            {
                _ColorFrame     = new RealColorFrame    (null);
                _BodyIndexFrame = new RealBodyIndexFrame(null);
                _DepthFrame     = new RealDepthFrame    (null);
                _BodyFrame      = new RealBodyFrame     (null);

                return;
            }

            using (var colorFrame     = sourceFrame.ColorFrameReference    .AcquireFrame())
                _ColorFrame           = new RealColorFrame    (colorFrame);
            using (var bodyIndexFrame = sourceFrame.BodyIndexFrameReference.AcquireFrame())
                _BodyIndexFrame       = new RealBodyIndexFrame(bodyIndexFrame);
            using (var depthFrame     = sourceFrame.DepthFrameReference    .AcquireFrame())
                _DepthFrame           = new RealDepthFrame    (depthFrame);
            using (var bodyFrame      = sourceFrame.BodyFrameReference     .AcquireFrame())
                _BodyFrame            = new RealBodyFrame     (bodyFrame);
        }
    }
}